# Seeds

This is a plural model for multiple Seed.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_schema** | [**EmbeddedModelSchema**](EmbeddedModelSchema.md) |  | [optional] 
**iterable** | [**List[Seed]**](Seed.md) |  | 

## Example

```python
from openapi_client.models.seeds import Seeds

# TODO update the JSON string below
json = "{}"
# create an instance of Seeds from a JSON string
seeds_instance = Seeds.from_json(json)
# print the JSON string representation of the object
print Seeds.to_json()

# convert the object into a dict
seeds_dict = seeds_instance.to_dict()
# create an instance of Seeds from a dict
seeds_form_dict = seeds.from_dict(seeds_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


